@@ -15,7 +15,7 @@ export class NotePagesToNotes extends CursorDataMigration {
               created_at,
               updated_at,
               deleted_at,
-              note_type,
+              note_type_id,
               record_id,
               record_type,
               date,
@@ -31,7 +31,7 @@ export class NotePagesToNotes extends CursorDataMigration {
               note_items.created_at,
               note_items.updated_at,
               note_items.deleted_at,
-              note_pages.note_type,
+              note_pages.note_type_id,
               note_pages.record_id,
               note_pages.record_type,
               note_items.date,
