@@ -5,6 +5,8 @@ export const USER_PREFERENCES_KEYS = {
   SELECTED_GRAPHED_CHARTS_ON_FILTER: 'selectedGraphedChartsOnFilter',
   SELECTED_CHART_TYPE_ID: 'selectedChartTypeId',
   LOCATION_BOOKING_FILTERS: 'locationBookingFilters',
+  LOCATION_BOOKING_VIEW_TYPE: 'locationBookingViewType',
   OUTPATIENT_APPOINTMENT_FILTERS: 'outpatientAppointmentFilters',
   OUTPATIENT_APPOINTMENT_GROUP_BY: 'outpatientAppointmentGroupBy',
+  LOCATION_ASSIGNMENT_SELECTED_FACILITY: 'locationAssignmentSelectedFacility',
 };
